@@ -2,6 +2,7 @@ from datetime import datetime, timedelta
 
 from . import errors
 import pytest
+from conftest import five_column_dataset
 
 
 class TestGeneral:
@@ -438,7 +439,7 @@ class TestGetMetaData:
 class TestLoadData:
     @pytest.mark.destination
     @pytest.mark.load_data
-    def test_load_data_append(self, connector, good_object_id, m, _append, five_column_dataset):
+    def test_load_data_append(self, connector, good_object_id, m, _append):
         try:
             connector.load_data(five_column_dataset(100), good_object_id, m, _append, batch_number=1, total_batches=1)
         except Exception as e:
@@ -446,7 +447,7 @@ class TestLoadData:
 
     @pytest.mark.destination
     @pytest.mark.load_data
-    def test_load_data_replace(self, connector, good_object_id, m, _replace, five_column_dataset):
+    def test_load_data_replace(self, connector, good_object_id, m, _replace):
         try:
             connector.load_data(five_column_dataset(100), good_object_id, m, _replace, batch_number=1, total_batches=1)
         except Exception as e:
@@ -454,7 +455,7 @@ class TestLoadData:
 
     @pytest.mark.destination
     @pytest.mark.load_data
-    def test_load_data_create_new_table(self, connector, bad_object_id, m, _replace, five_column_dataset):
+    def test_load_data_create_new_table(self, connector, bad_object_id, m, _replace):
         # FIXME: a potential issue here is that i do not have object name validation for "_bad" on an object_id
         connector.load_data(five_column_dataset(100), bad_object_id, m, _replace, batch_number=1, total_batches=1)
         connector.authenticate()
